#ifndef DIRECT_CTRL_H
#define DIRECT_CTRL_H

/*!
  \file
  \brief ʃfoCX̒ڐ

  ʃfoCX𒼐ڐ䂷

  \author Satofumi KAMIMURA

  $Id$
*/

#include "motorCtrl.h"


/*!
  \brief foCXڐ̒萔
*/
enum DirectDeviceCtrlMode {
  DIRECT_MODE_FREE = MTR_MODE_FREE,
  DIRECT_MODE_CW = MTR_MODE_CW_BREAK,
  DIRECT_MODE_CCW = MTR_MODE_CCW_BREAK,
  DIRECT_MODE_NONE,
  FREE = DIRECT_MODE_FREE,
  CW = DIRECT_MODE_CW,
  CCW = DIRECT_MODE_CCW,
};


/*!
  \brief [^ڐp̍\

  [^AGR[_𒼐ڐ䂷邽߂̃p[^Ǘ
*/
typedef struct {
  unsigned char pwm;		/* PWM */
  unsigned char mode;		/* [h */
} directDeviceInfo_t;


//#include "cpp_extern_macro.h"
BEGIN_C_DECLS;

/*!
  \brief foCXڐ̏
*/
extern void initDirectInfo(directDeviceInfo_t *direct);

END_C_DECLS;
#endif /* !DIRECT_CTRL */
